parameters: The method returns all parameters supported by specific...

View source: R/solvers.R

parametersR Documentation

The method returns all parameters supported by specific solver

Description

The method returns all parameters supported by specific solver

Usage

parameters(solver)

Arguments

solver

a solver object

Value

A table containing parameter names and possible values for each parameter.


mwcsr documentation built on Sept. 23, 2026, 5:06 p.m.